# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.processor_run_status import ProcessorRunStatus
from ..types.run_metadata import RunMetadata
from ..types.updated_at import UpdatedAt
from .file_summary import FileSummaryParams
from .run_usage import RunUsageParams
from .split_config import SplitConfigParams
from .split_output import SplitOutputParams
from .splitter_summary import SplitterSummaryParams
from .splitter_version_summary import SplitterVersionSummaryParams


class SplitRunParams(typing_extensions.TypedDict):
    """
    Split run object.
    """

    object: typing.Literal["split_run"]
    """
    The type of object. Will always be `"split_run"`.
    """

    id: str
    """
    The unique identifier for this split run.
    
    Example: `"splr_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    splitter: typing.Optional[SplitterSummaryParams]
    """
    The splitter that was used for this run.
    
    **Availability:** Present when a splitter reference was provided. Not present when using inline `config`.
    """

    splitter_version: typing_extensions.Annotated[
        typing.Optional[SplitterVersionSummaryParams], FieldMetadata(alias="splitterVersion")
    ]
    """
    The version of the splitter that was used for this run.
    
    **Availability:** Present when a splitter reference was provided. Not present when using inline `config`.
    """

    status: ProcessorRunStatus
    output: typing.Optional[SplitOutputParams]
    """
    The final output, either reviewed or initial.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    initial_output: typing_extensions.Annotated[
        typing.Optional[SplitOutputParams], FieldMetadata(alias="initialOutput")
    ]
    """
    The initial output from the split run, before any review edits.
    
    **Availability:** Present when `reviewed` is `true`.
    """

    reviewed_output: typing_extensions.Annotated[
        typing.Optional[SplitOutputParams], FieldMetadata(alias="reviewedOutput")
    ]
    """
    The output after human review.
    
    **Availability:** Present when `reviewed` is `true`.
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")]
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    
    Possible values include:
    * `ABORTED` - The run was aborted by the user
    * `INTERNAL_ERROR` - An unexpected internal error occurred
    * `FAILED_TO_PROCESS_FILE` - Failed to process the file (e.g., OCR failure, file access issues)
    * `INVALID_PROCESSOR` - The processor configuration is invalid
    * `INVALID_CONFIGURATION` - The provided configuration is incompatible with the selected model
    * `PARSING_ERROR` - Failed to parse the splitting output
    * `PRE_PROCESSING_FAILURE` - An error occurred during preprocessing
    * `POST_PROCESSING_FAILURE` - An error occurred during postprocessing
    * `OUT_OF_CREDITS` - Insufficient credits to run the splitter
    
    **Note:** Additional failure reasons may be added in the future. Your integration should handle unknown values gracefully.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")]
    """
    A detailed message about the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    metadata: typing.Optional[RunMetadata]
    """
    Any metadata that was provided when creating the split run.
    
    **Availability:** Present when metadata was provided during creation.
    """

    reviewed: bool
    """
    Indicates whether the run has been reviewed by a human.
    """

    edited: bool
    """
    Indicates whether the run results have been edited during review.
    """

    config: SplitConfigParams
    """
    The configuration used for this split run.
    """

    file: FileSummaryParams
    """
    The file that was processed.
    """

    parse_run_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="parseRunId")]
    """
    The ID of the parse run that was used for this split run.
    
    **Availability:** Present when a parse run was created.
    """

    dashboard_url: typing_extensions.Annotated[str, FieldMetadata(alias="dashboardUrl")]
    """
    The URL to view the split run in the Extend dashboard.
    """

    usage: typing.Optional[RunUsageParams]
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.run_metadata import RunMetadata
from ...types.run_secrets import RunSecrets
from .workflow_runs_create_batch_request_inputs_item_file import WorkflowRunsCreateBatchRequestInputsItemFile


class WorkflowRunsCreateBatchRequestInputsItem(UncheckedBaseModel):
    file: WorkflowRunsCreateBatchRequestInputsItemFile = pydantic.Field()
    """
    The file to be processed. Files can be provided as a URL, an Extend file ID, or raw text.
    """

    metadata: typing.Optional[RunMetadata] = None
    secrets: typing.Optional[RunSecrets] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class WebhookEndpointEventType(enum.StrEnum):
    """
    Event types available for webhook endpoints at the global level. Includes run events and resource lifecycle events.
    """

    PARSE_RUN_PROCESSED = "parse_run.processed"
    PARSE_RUN_FAILED = "parse_run.failed"
    EDIT_RUN_PROCESSED = "edit_run.processed"
    EDIT_RUN_FAILED = "edit_run.failed"
    EXTRACT_RUN_PROCESSED = "extract_run.processed"
    EXTRACT_RUN_FAILED = "extract_run.failed"
    CLASSIFY_RUN_PROCESSED = "classify_run.processed"
    CLASSIFY_RUN_FAILED = "classify_run.failed"
    SPLIT_RUN_PROCESSED = "split_run.processed"
    SPLIT_RUN_FAILED = "split_run.failed"
    EXTRACTOR_CREATED = "extractor.created"
    EXTRACTOR_UPDATED = "extractor.updated"
    EXTRACTOR_DELETED = "extractor.deleted"
    EXTRACTOR_DRAFT_UPDATED = "extractor.draft.updated"
    EXTRACTOR_VERSION_PUBLISHED = "extractor.version.published"
    CLASSIFIER_CREATED = "classifier.created"
    CLASSIFIER_UPDATED = "classifier.updated"
    CLASSIFIER_DELETED = "classifier.deleted"
    CLASSIFIER_DRAFT_UPDATED = "classifier.draft.updated"
    CLASSIFIER_VERSION_PUBLISHED = "classifier.version.published"
    SPLITTER_CREATED = "splitter.created"
    SPLITTER_UPDATED = "splitter.updated"
    SPLITTER_DELETED = "splitter.deleted"
    SPLITTER_DRAFT_UPDATED = "splitter.draft.updated"
    SPLITTER_VERSION_PUBLISHED = "splitter.version.published"
    WORKFLOW_CREATED = "workflow.created"
    WORKFLOW_DEPLOYED = "workflow.deployed"
    WORKFLOW_DELETED = "workflow.deleted"
    _UNKNOWN = "__WEBHOOKENDPOINTEVENTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "WebhookEndpointEventType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        parse_run_processed: typing.Callable[[], T_Result],
        parse_run_failed: typing.Callable[[], T_Result],
        edit_run_processed: typing.Callable[[], T_Result],
        edit_run_failed: typing.Callable[[], T_Result],
        extract_run_processed: typing.Callable[[], T_Result],
        extract_run_failed: typing.Callable[[], T_Result],
        classify_run_processed: typing.Callable[[], T_Result],
        classify_run_failed: typing.Callable[[], T_Result],
        split_run_processed: typing.Callable[[], T_Result],
        split_run_failed: typing.Callable[[], T_Result],
        extractor_created: typing.Callable[[], T_Result],
        extractor_updated: typing.Callable[[], T_Result],
        extractor_deleted: typing.Callable[[], T_Result],
        extractor_draft_updated: typing.Callable[[], T_Result],
        extractor_version_published: typing.Callable[[], T_Result],
        classifier_created: typing.Callable[[], T_Result],
        classifier_updated: typing.Callable[[], T_Result],
        classifier_deleted: typing.Callable[[], T_Result],
        classifier_draft_updated: typing.Callable[[], T_Result],
        classifier_version_published: typing.Callable[[], T_Result],
        splitter_created: typing.Callable[[], T_Result],
        splitter_updated: typing.Callable[[], T_Result],
        splitter_deleted: typing.Callable[[], T_Result],
        splitter_draft_updated: typing.Callable[[], T_Result],
        splitter_version_published: typing.Callable[[], T_Result],
        workflow_created: typing.Callable[[], T_Result],
        workflow_deployed: typing.Callable[[], T_Result],
        workflow_deleted: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is WebhookEndpointEventType.PARSE_RUN_PROCESSED:
            return parse_run_processed()
        if self is WebhookEndpointEventType.PARSE_RUN_FAILED:
            return parse_run_failed()
        if self is WebhookEndpointEventType.EDIT_RUN_PROCESSED:
            return edit_run_processed()
        if self is WebhookEndpointEventType.EDIT_RUN_FAILED:
            return edit_run_failed()
        if self is WebhookEndpointEventType.EXTRACT_RUN_PROCESSED:
            return extract_run_processed()
        if self is WebhookEndpointEventType.EXTRACT_RUN_FAILED:
            return extract_run_failed()
        if self is WebhookEndpointEventType.CLASSIFY_RUN_PROCESSED:
            return classify_run_processed()
        if self is WebhookEndpointEventType.CLASSIFY_RUN_FAILED:
            return classify_run_failed()
        if self is WebhookEndpointEventType.SPLIT_RUN_PROCESSED:
            return split_run_processed()
        if self is WebhookEndpointEventType.SPLIT_RUN_FAILED:
            return split_run_failed()
        if self is WebhookEndpointEventType.EXTRACTOR_CREATED:
            return extractor_created()
        if self is WebhookEndpointEventType.EXTRACTOR_UPDATED:
            return extractor_updated()
        if self is WebhookEndpointEventType.EXTRACTOR_DELETED:
            return extractor_deleted()
        if self is WebhookEndpointEventType.EXTRACTOR_DRAFT_UPDATED:
            return extractor_draft_updated()
        if self is WebhookEndpointEventType.EXTRACTOR_VERSION_PUBLISHED:
            return extractor_version_published()
        if self is WebhookEndpointEventType.CLASSIFIER_CREATED:
            return classifier_created()
        if self is WebhookEndpointEventType.CLASSIFIER_UPDATED:
            return classifier_updated()
        if self is WebhookEndpointEventType.CLASSIFIER_DELETED:
            return classifier_deleted()
        if self is WebhookEndpointEventType.CLASSIFIER_DRAFT_UPDATED:
            return classifier_draft_updated()
        if self is WebhookEndpointEventType.CLASSIFIER_VERSION_PUBLISHED:
            return classifier_version_published()
        if self is WebhookEndpointEventType.SPLITTER_CREATED:
            return splitter_created()
        if self is WebhookEndpointEventType.SPLITTER_UPDATED:
            return splitter_updated()
        if self is WebhookEndpointEventType.SPLITTER_DELETED:
            return splitter_deleted()
        if self is WebhookEndpointEventType.SPLITTER_DRAFT_UPDATED:
            return splitter_draft_updated()
        if self is WebhookEndpointEventType.SPLITTER_VERSION_PUBLISHED:
            return splitter_version_published()
        if self is WebhookEndpointEventType.WORKFLOW_CREATED:
            return workflow_created()
        if self is WebhookEndpointEventType.WORKFLOW_DEPLOYED:
            return workflow_deployed()
        if self is WebhookEndpointEventType.WORKFLOW_DELETED:
            return workflow_deleted()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .classifier import ClassifierParams
from .classifier_version import ClassifierVersionParams
from .classify_run import ClassifyRunParams
from .edit_run import EditRunParams
from .extract_run import ExtractRunParams
from .extractor import ExtractorParams
from .extractor_version import ExtractorVersionParams
from .parse_run_status import ParseRunStatusParams
from .split_run import SplitRunParams
from .splitter import SplitterParams
from .splitter_version import SplitterVersionParams
from .step_run import StepRunParams
from .workflow import WorkflowParams
from .workflow_run import WorkflowRunParams


class WebhookEvent_WorkflowRunCompletedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow_run.completed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowRunParams


class WebhookEvent_WorkflowRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowRunParams


class WebhookEvent_WorkflowRunNeedsReviewParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.needs_review"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowRunParams


class WebhookEvent_WorkflowRunRejectedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow_run.rejected"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowRunParams


class WebhookEvent_WorkflowRunCancelledParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow_run.cancelled"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowRunParams


class WebhookEvent_WorkflowRunStepRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.step_run.processed"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: StepRunParams


class WebhookEvent_ExtractRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extract_run.processed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractRunParams


class WebhookEvent_ExtractRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extract_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractRunParams


class WebhookEvent_ClassifyRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["classify_run.processed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifyRunParams


class WebhookEvent_ClassifyRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["classify_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifyRunParams


class WebhookEvent_SplitRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["split_run.processed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitRunParams


class WebhookEvent_SplitRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["split_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitRunParams


class WebhookEvent_ParseRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["parse_run.processed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ParseRunStatusParams


class WebhookEvent_ParseRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["parse_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ParseRunStatusParams


class WebhookEvent_EditRunProcessedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["edit_run.processed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: EditRunParams


class WebhookEvent_EditRunFailedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["edit_run.failed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: EditRunParams


class WebhookEvent_WorkflowCreatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow.created"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowParams


class WebhookEvent_WorkflowDeployedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow.deployed"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowParams


class WebhookEvent_WorkflowDeletedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["workflow.deleted"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: WorkflowParams


class WebhookEvent_ExtractorCreatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extractor.created"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractorParams


class WebhookEvent_ExtractorUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extractor.updated"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractorParams


class WebhookEvent_ExtractorDeletedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extractor.deleted"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractorParams


class WebhookEvent_ExtractorDraftUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["extractor.draft.updated"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractorParams


class WebhookEvent_ExtractorVersionPublishedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["extractor.version.published"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ExtractorVersionParams


class WebhookEvent_ClassifierCreatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["classifier.created"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifierParams


class WebhookEvent_ClassifierUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["classifier.updated"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifierParams


class WebhookEvent_ClassifierDeletedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["classifier.deleted"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifierParams


class WebhookEvent_ClassifierDraftUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["classifier.draft.updated"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifierParams


class WebhookEvent_ClassifierVersionPublishedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["classifier.version.published"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: ClassifierVersionParams


class WebhookEvent_SplitterCreatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["splitter.created"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitterParams


class WebhookEvent_SplitterUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["splitter.updated"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitterParams


class WebhookEvent_SplitterDeletedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["splitter.deleted"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitterParams


class WebhookEvent_SplitterDraftUpdatedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[typing.Literal["splitter.draft.updated"], FieldMetadata(alias="eventType")]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitterParams


class WebhookEvent_SplitterVersionPublishedParams(typing_extensions.TypedDict):
    event_type: typing_extensions.Annotated[
        typing.Literal["splitter.version.published"], FieldMetadata(alias="eventType")
    ]
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    payload: SplitterVersionParams


WebhookEventParams = typing.Union[
    WebhookEvent_WorkflowRunCompletedParams,
    WebhookEvent_WorkflowRunFailedParams,
    WebhookEvent_WorkflowRunNeedsReviewParams,
    WebhookEvent_WorkflowRunRejectedParams,
    WebhookEvent_WorkflowRunCancelledParams,
    WebhookEvent_WorkflowRunStepRunProcessedParams,
    WebhookEvent_ExtractRunProcessedParams,
    WebhookEvent_ExtractRunFailedParams,
    WebhookEvent_ClassifyRunProcessedParams,
    WebhookEvent_ClassifyRunFailedParams,
    WebhookEvent_SplitRunProcessedParams,
    WebhookEvent_SplitRunFailedParams,
    WebhookEvent_ParseRunProcessedParams,
    WebhookEvent_ParseRunFailedParams,
    WebhookEvent_EditRunProcessedParams,
    WebhookEvent_EditRunFailedParams,
    WebhookEvent_WorkflowCreatedParams,
    WebhookEvent_WorkflowDeployedParams,
    WebhookEvent_WorkflowDeletedParams,
    WebhookEvent_ExtractorCreatedParams,
    WebhookEvent_ExtractorUpdatedParams,
    WebhookEvent_ExtractorDeletedParams,
    WebhookEvent_ExtractorDraftUpdatedParams,
    WebhookEvent_ExtractorVersionPublishedParams,
    WebhookEvent_ClassifierCreatedParams,
    WebhookEvent_ClassifierUpdatedParams,
    WebhookEvent_ClassifierDeletedParams,
    WebhookEvent_ClassifierDraftUpdatedParams,
    WebhookEvent_ClassifierVersionPublishedParams,
    WebhookEvent_SplitterCreatedParams,
    WebhookEvent_SplitterUpdatedParams,
    WebhookEvent_SplitterDeletedParams,
    WebhookEvent_SplitterDraftUpdatedParams,
    WebhookEvent_SplitterVersionPublishedParams,
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
        ProcessorCreateResponse,
        ProcessorListRequestSortBy,
        ProcessorListRequestSortDir,
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
        ProcessorUpdateResponse,
    )
    from .requests import (
        ProcessorCreateRequestConfigParams,
        ProcessorCreateRequestConfig_ClassifyParams,
        ProcessorCreateRequestConfig_ExtractParams,
        ProcessorCreateRequestConfig_SplitterParams,
        ProcessorCreateResponseParams,
        ProcessorUpdateRequestConfigParams,
        ProcessorUpdateRequestConfig_ClassifyParams,
        ProcessorUpdateRequestConfig_ExtractParams,
        ProcessorUpdateRequestConfig_SplitterParams,
        ProcessorUpdateResponseParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorCreateRequestConfig": ".types",
    "ProcessorCreateRequestConfigParams": ".requests",
    "ProcessorCreateRequestConfig_Classify": ".types",
    "ProcessorCreateRequestConfig_ClassifyParams": ".requests",
    "ProcessorCreateRequestConfig_Extract": ".types",
    "ProcessorCreateRequestConfig_ExtractParams": ".requests",
    "ProcessorCreateRequestConfig_Splitter": ".types",
    "ProcessorCreateRequestConfig_SplitterParams": ".requests",
    "ProcessorCreateResponse": ".types",
    "ProcessorCreateResponseParams": ".requests",
    "ProcessorListRequestSortBy": ".types",
    "ProcessorListRequestSortDir": ".types",
    "ProcessorUpdateRequestConfig": ".types",
    "ProcessorUpdateRequestConfigParams": ".requests",
    "ProcessorUpdateRequestConfig_Classify": ".types",
    "ProcessorUpdateRequestConfig_ClassifyParams": ".requests",
    "ProcessorUpdateRequestConfig_Extract": ".types",
    "ProcessorUpdateRequestConfig_ExtractParams": ".requests",
    "ProcessorUpdateRequestConfig_Splitter": ".types",
    "ProcessorUpdateRequestConfig_SplitterParams": ".requests",
    "ProcessorUpdateResponse": ".types",
    "ProcessorUpdateResponseParams": ".requests",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfigParams",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_ClassifyParams",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_ExtractParams",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateRequestConfig_SplitterParams",
    "ProcessorCreateResponse",
    "ProcessorCreateResponseParams",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfigParams",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_ClassifyParams",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_ExtractParams",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateRequestConfig_SplitterParams",
    "ProcessorUpdateResponse",
    "ProcessorUpdateResponseParams",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class WorkflowVersion(UncheckedBaseModel):
    object: typing.Literal["workflow_version"] = pydantic.Field(default="workflow_version")
    """
    The type of object. In this case, it will always be `"workflow_version"`.
    """

    id: str = pydantic.Field()
    """
    The ID of the workflow version.
    
    Example: `"workflow_version_Zk9mNP12Qw4-yTv8BdR3H"`
    """

    version: str = pydantic.Field()
    """
    The version of the workflow version.
    
    Example: `"3"`
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the workflow version.
    
    Example: `"Invoice Processing"`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..requests.classify_config import ClassifyConfigParams
from ..types.classifier_version import ClassifierVersion
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.release_type import ReleaseType
from ..types.sort_dir import SortDir
from ..types.version_description import VersionDescription
from .raw_client import AsyncRawClassifierVersionsClient, RawClassifierVersionsClient
from .types.classifier_versions_list_response import ClassifierVersionsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ClassifierVersionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawClassifierVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawClassifierVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawClassifierVersionsClient
        """
        return self._raw_client

    def list(
        self,
        classifier_id: str,
        *,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifierVersionsListResponse:
        """
        This endpoint allows you to fetch all versions of a given classifier, including the current `draft` version.

        Versions are returned in descending order of creation (newest first) with the `draft` version first. The `draft` version is the latest unpublished version of the classifier, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersionsListResponse
            Successfully retrieved classifier versions

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classifier_versions.list(
            classifier_id="classifier_id_here",
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            classifier_id,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        classifier_id: str,
        *,
        release_type: ReleaseType,
        description: typing.Optional[VersionDescription] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifierVersion:
        """
        This endpoint allows you to publish a new version of an existing classifier. Publishing a new version creates a snapshot of the classifier's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this classifier. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ReleaseType

        description : typing.Optional[VersionDescription]

        config : typing.Optional[ClassifyConfigParams]
            The configuration for this version of the classifier.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersion
            Successfully published classifier version

        Examples
        --------
        from extend_ai import Extend, ReleaseType

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classifier_versions.create(
            classifier_id="classifier_id_here",
            release_type=ReleaseType.MINOR,
            description="Added new document classification type",
        )
        """
        _response = self._raw_client.create(
            classifier_id,
            release_type=release_type,
            description=description,
            config=config,
            request_options=request_options,
        )
        return _response.data

    def retrieve(
        self, classifier_id: str, version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ClassifierVersion:
        """
        Retrieve a specific version of a classifier in Extend

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        version_id : str
            The ID of the specific classifier version.

            Example: `"clsv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersion
            Successfully retrieved classifier version

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classifier_versions.retrieve(
            classifier_id="classifier_id_here",
            version_id="classifier_version_id_here",
        )
        """
        _response = self._raw_client.retrieve(classifier_id, version_id, request_options=request_options)
        return _response.data


class AsyncClassifierVersionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawClassifierVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawClassifierVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawClassifierVersionsClient
        """
        return self._raw_client

    async def list(
        self,
        classifier_id: str,
        *,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifierVersionsListResponse:
        """
        This endpoint allows you to fetch all versions of a given classifier, including the current `draft` version.

        Versions are returned in descending order of creation (newest first) with the `draft` version first. The `draft` version is the latest unpublished version of the classifier, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersionsListResponse
            Successfully retrieved classifier versions

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classifier_versions.list(
                classifier_id="classifier_id_here",
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            classifier_id,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        classifier_id: str,
        *,
        release_type: ReleaseType,
        description: typing.Optional[VersionDescription] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifierVersion:
        """
        This endpoint allows you to publish a new version of an existing classifier. Publishing a new version creates a snapshot of the classifier's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this classifier. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ReleaseType

        description : typing.Optional[VersionDescription]

        config : typing.Optional[ClassifyConfigParams]
            The configuration for this version of the classifier.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersion
            Successfully published classifier version

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend, ReleaseType

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classifier_versions.create(
                classifier_id="classifier_id_here",
                release_type=ReleaseType.MINOR,
                description="Added new document classification type",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            classifier_id,
            release_type=release_type,
            description=description,
            config=config,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(
        self, classifier_id: str, version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ClassifierVersion:
        """
        Retrieve a specific version of a classifier in Extend

        Parameters
        ----------
        classifier_id : str
            The ID of the classifier.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        version_id : str
            The ID of the specific classifier version.

            Example: `"clsv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifierVersion
            Successfully retrieved classifier version

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classifier_versions.retrieve(
                classifier_id="classifier_id_here",
                version_id="classifier_version_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(classifier_id, version_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .file_from_id import FileFromIdParams
from .file_from_text import FileFromTextParams
from .file_from_url import FileFromUrlParams

ExtractRequestFileParams = typing.Union[FileFromUrlParams, FileFromIdParams, FileFromTextParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .created_at import CreatedAt


class ExtractorVersionSummary(UncheckedBaseModel):
    object: typing.Literal["extractor_version"] = pydantic.Field(default="extractor_version")
    """
    The type of object. Will always be `"extractor_version"`.
    """

    id: str = pydantic.Field()
    """
    The unique identifier for this version of the extractor.
    
    Example: `"exv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    A description of this version of the extractor.
    
    Example: `"Updated extraction fields for new invoice format"`
    """

    version: str = pydantic.Field()
    """
    The version number or identifier for this specific version of the extractor. The draft version will have version="draft".
    
    Examples: `"1.0"`, `"2.1"`, `"draft"`
    """

    extractor_id: typing_extensions.Annotated[str, FieldMetadata(alias="extractorId")] = pydantic.Field(
        alias="extractorId"
    )
    """
    The ID of the extractor that this version belongs to.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .file_from_id import FileFromId
from .file_from_text import FileFromText
from .file_from_url import FileFromUrl

ClassifyRequestFile = typing.Union[FileFromUrl, FileFromId, FileFromText]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.figure_details_figure_type import FigureDetailsFigureType


class FigureDetailsParams(typing_extensions.TypedDict):
    """
    Details for figure blocks
    """

    type: typing.Literal["figure_details"]
    """
    Indicates this is a figure details object
    """

    image_url: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="imageUrl")]]
    """
    URL to the clipped/segmented figure image. Only set if the option `figureImageClippingEnabled` in the input is `true`, which it is by default.
    """

    figure_type: typing_extensions.NotRequired[
        typing_extensions.Annotated[FigureDetailsFigureType, FieldMetadata(alias="figureType")]
    ]
    """
    The refined type of figure - only set when figure classification and summarization is enabled. Possible values:
    
    * `image`: A photographic image
    * `chart`: A data chart or graph
    * `diagram`: A schematic or diagram
    * `logo`: A company or brand logo
    * `other`: Any other type of figure
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class FileFromUrlParams(typing_extensions.TypedDict):
    url: str
    """
    A URL to download the file. For production use cases, we recommend using presigned URLs with a 5-15 minute expiration time.
    
    Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of the file. If not set, the file name is taken from the URL.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class SplitClassificationParams(typing_extensions.TypedDict):
    """
    A classification for document splitting. Extends the base Classification with an optional `identifierKey` field for per-type identifier extraction rules.
    """

    id: str
    """
    Unique identifier for the classification. We recommend lowercase, underscore-separated format.
    """

    type: str
    """
    Type identifier for the classification.
    """

    description: str
    """
    A detailed description of the classification.
    """

    identifier_key: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="identifierKey")]
    ]
    """
    A natural-language rule describing how to extract a unique identifier for subdocuments of this type. For example, `"Extract the invoice number from the document header"`.
    
    When provided, the splitter will extract the specified identifier for each subdocument of this type and include it in the output as the `identifier` field. This enables merging of related subdocuments that share the same extracted identifier.
    
    **Availability:** Supported on `splitting_light` >= 1.3.0 and `splitting_performance` >= 1.5.0. If provided on older versions, this field is accepted but ignored.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..requests.split_config import SplitConfigParams
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_by import SortBy
from ..types.sort_dir import SortDir
from ..types.splitter import Splitter
from .raw_client import AsyncRawSplittersClient, RawSplittersClient
from .types.splitters_list_response import SplittersListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SplittersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSplittersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSplittersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSplittersClient
        """
        return self._raw_client

    def list(
        self,
        *,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplittersListResponse:
        """
        List all splitters.

        Returns a summary of each splitter. Use `GET /splitters/{id}` to retrieve the full object including `draftVersion`.

        Parameters
        ----------
        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplittersListResponse
            Successfully retrieved splitters

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.splitters.list(
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            sort_by=sort_by,
            sort_dir=sort_dir,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        name: str,
        clone_splitter_id: typing.Optional[str] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Splitter:
        """
        Create a new splitter.

        Parameters
        ----------
        name : str
            The name of the splitter.

        clone_splitter_id : typing.Optional[str]
            The ID of an existing splitter to clone. If provided, the new splitter will be created with the same config as the splitter with this ID. Cannot be provided together with `config`.

            Example: `"spl_BMdfq_yWM3sT-ZzvCnA3f"`

        config : typing.Optional[SplitConfigParams]
            The configuration for the splitter. Cannot be provided together with `cloneSplitterId`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter created successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.splitters.create(
            name="Document Splitter",
            config={
                "split_classifications": [
                    {
                        "id": "invoice",
                        "type": "invoice",
                        "description": "An invoice or bill for goods or services",
                        "identifier_key": "invoice number from the document header",
                    },
                    {
                        "id": "receipt",
                        "type": "receipt",
                        "description": "A receipt confirming payment",
                        "identifier_key": "receipt number",
                    },
                    {
                        "id": "other",
                        "type": "other",
                        "description": "Any other document type",
                    },
                ]
            },
        )
        """
        _response = self._raw_client.create(
            name=name, clone_splitter_id=clone_splitter_id, config=config, request_options=request_options
        )
        return _response.data

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> Splitter:
        """
        Get details of a splitter.

        Parameters
        ----------
        id : str
            The ID of the splitter to get.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter details

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.splitters.retrieve(
            id="splitter_id_here",
        )
        """
        _response = self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Splitter:
        """
        Update an existing splitter.

        Parameters
        ----------
        id : str
            The ID of the splitter to update.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name of the splitter.

        config : typing.Optional[SplitConfigParams]
            The new configuration for the splitter. This will update the draft version of the splitter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter updated successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.splitters.update(
            id="splitter_id_here",
            name="Document Splitter v2",
        )
        """
        _response = self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data


class AsyncSplittersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSplittersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSplittersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSplittersClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplittersListResponse:
        """
        List all splitters.

        Returns a summary of each splitter. Use `GET /splitters/{id}` to retrieve the full object including `draftVersion`.

        Parameters
        ----------
        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplittersListResponse
            Successfully retrieved splitters

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.splitters.list(
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            sort_by=sort_by,
            sort_dir=sort_dir,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        name: str,
        clone_splitter_id: typing.Optional[str] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Splitter:
        """
        Create a new splitter.

        Parameters
        ----------
        name : str
            The name of the splitter.

        clone_splitter_id : typing.Optional[str]
            The ID of an existing splitter to clone. If provided, the new splitter will be created with the same config as the splitter with this ID. Cannot be provided together with `config`.

            Example: `"spl_BMdfq_yWM3sT-ZzvCnA3f"`

        config : typing.Optional[SplitConfigParams]
            The configuration for the splitter. Cannot be provided together with `cloneSplitterId`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter created successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.splitters.create(
                name="Document Splitter",
                config={
                    "split_classifications": [
                        {
                            "id": "invoice",
                            "type": "invoice",
                            "description": "An invoice or bill for goods or services",
                            "identifier_key": "invoice number from the document header",
                        },
                        {
                            "id": "receipt",
                            "type": "receipt",
                            "description": "A receipt confirming payment",
                            "identifier_key": "receipt number",
                        },
                        {
                            "id": "other",
                            "type": "other",
                            "description": "Any other document type",
                        },
                    ]
                },
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name, clone_splitter_id=clone_splitter_id, config=config, request_options=request_options
        )
        return _response.data

    async def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> Splitter:
        """
        Get details of a splitter.

        Parameters
        ----------
        id : str
            The ID of the splitter to get.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter details

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.splitters.retrieve(
                id="splitter_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    async def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Splitter:
        """
        Update an existing splitter.

        Parameters
        ----------
        id : str
            The ID of the splitter to update.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name of the splitter.

        config : typing.Optional[SplitConfigParams]
            The new configuration for the splitter. This will update the draft version of the splitter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Splitter
            Splitter updated successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.splitters.update(
                id="splitter_id_here",
                name="Document Splitter v2",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditObjectJson(UncheckedBaseModel):
    """
    Schema definition for an object field in a PDF edit schema. Used for signature fields and as items schema for arrays/tables.
    """

    type: typing.Optional[typing.Literal["object"]] = pydantic.Field(default=None)
    """
    Must be "object" for object schemas
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the field
    """

    extend_edit_field_type: typing_extensions.Annotated[
        typing.Optional[typing.Literal["signature"]], FieldMetadata(alias="extend_edit:field_type")
    ] = pydantic.Field(alias="extend_edit:field_type", default=None)
    """
    The PDF field type. For object schemas, must be "signature".
    """

    properties: typing.Optional[typing.Dict[str, "EditJson"]] = pydantic.Field(default=None)
    """
    Nested properties. Each property follows the EditJSON structure.
    """

    required: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of required property names
    """

    additional_properties: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="additionalProperties")
    ] = pydantic.Field(alias="additionalProperties", default=None)
    """
    Whether additional properties are allowed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .edit_json import EditJson  # noqa: E402, I001

update_forward_refs(EditObjectJson, EditJson=EditJson)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .legacy_splitter_output_splits_item import LegacySplitterOutputSplitsItemParams


class LegacySplitterOutputParams(typing_extensions.TypedDict):
    splits: typing.Sequence[LegacySplitterOutputSplitsItemParams]
    is_external: typing_extensions.NotRequired[typing_extensions.Annotated[bool, FieldMetadata(alias="isExternal")]]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .parse_run import ParseRunParams


class ParseResultParams(typing_extensions.TypedDict):
    """
    The result of a parse step.
    """

    parse_run: typing_extensions.Annotated[ParseRunParams, FieldMetadata(alias="parseRun")]
    """
    The parse run that was executed.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel


class WorkflowRunsCreateBatchResponse(UncheckedBaseModel):
    batch_id: typing_extensions.Annotated[str, FieldMetadata(alias="batchId")] = pydantic.Field(alias="batchId")
    """
    A unique identifier for the submitted batch. This ID can be used to correlate the workflow runs created by this request. You can find this `batchId` associated with individual runs when listing workflow runs or in webhook payloads.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.not_found_error import NotFoundError
from ..errors.unauthorized_error import UnauthorizedError
from .requests.processor_version_create_request_config import ProcessorVersionCreateRequestConfigParams
from .types.processor_version_create_request_release_type import ProcessorVersionCreateRequestReleaseType
from .types.processor_version_create_response import ProcessorVersionCreateResponse
from .types.processor_version_get_response import ProcessorVersionGetResponse
from .types.processor_version_list_response import ProcessorVersionListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawProcessorVersionClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ProcessorVersionListResponse]:
        """
        This endpoint allows you to fetch all versions of a given processor, including the current `draft` version.

        Versions are typically returned in descending order of creation (newest first), but this should be confirmed in the actual implementation.
        The `draft` version is the latest unpublished version of the processor, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        id : str
            The ID of the processor to retrieve versions for.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProcessorVersionListResponse]
            Successfully retrieved processor versions
        """
        _response = self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(id)}/versions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionListResponse,
                    construct_type(
                        type_=ProcessorVersionListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        id: str,
        *,
        release_type: ProcessorVersionCreateRequestReleaseType,
        description: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorVersionCreateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ProcessorVersionCreateResponse]:
        """
        This endpoint allows you to publish a new version of an existing processor. Publishing a new version creates a snapshot of the processor's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this processor. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        id : str
            The ID of the processor to publish a new version for.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ProcessorVersionCreateRequestReleaseType
            The type of release for this version. The two options are "major" and "minor", which will increment the version number accordingly.

        description : typing.Optional[str]
            A description of the changes in this version. This helps track the evolution of the processor over time.

        config : typing.Optional[ProcessorVersionCreateRequestConfigParams]
            The configuration for this version of the processor. The type of configuration must match the processor type.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProcessorVersionCreateResponse]
            Successfully published processor version
        """
        _response = self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(id)}/publish",
            method="POST",
            json={
                "releaseType": release_type,
                "description": description,
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ProcessorVersionCreateRequestConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionCreateResponse,
                    construct_type(
                        type_=ProcessorVersionCreateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, processor_id: str, processor_version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ProcessorVersionGetResponse]:
        """
        Retrieve a specific version of a processor in Extend

        Parameters
        ----------
        processor_id : str
            The ID of the processor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        processor_version_id : str
            The ID of the specific processor version to retrieve.

            Example: `"exv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProcessorVersionGetResponse]
            Successfully retrieved processor version
        """
        _response = self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(processor_id)}/versions/{jsonable_encoder(processor_version_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionGetResponse,
                    construct_type(
                        type_=ProcessorVersionGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawProcessorVersionClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ProcessorVersionListResponse]:
        """
        This endpoint allows you to fetch all versions of a given processor, including the current `draft` version.

        Versions are typically returned in descending order of creation (newest first), but this should be confirmed in the actual implementation.
        The `draft` version is the latest unpublished version of the processor, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        id : str
            The ID of the processor to retrieve versions for.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProcessorVersionListResponse]
            Successfully retrieved processor versions
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(id)}/versions",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionListResponse,
                    construct_type(
                        type_=ProcessorVersionListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        id: str,
        *,
        release_type: ProcessorVersionCreateRequestReleaseType,
        description: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorVersionCreateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ProcessorVersionCreateResponse]:
        """
        This endpoint allows you to publish a new version of an existing processor. Publishing a new version creates a snapshot of the processor's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this processor. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        id : str
            The ID of the processor to publish a new version for.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ProcessorVersionCreateRequestReleaseType
            The type of release for this version. The two options are "major" and "minor", which will increment the version number accordingly.

        description : typing.Optional[str]
            A description of the changes in this version. This helps track the evolution of the processor over time.

        config : typing.Optional[ProcessorVersionCreateRequestConfigParams]
            The configuration for this version of the processor. The type of configuration must match the processor type.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProcessorVersionCreateResponse]
            Successfully published processor version
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(id)}/publish",
            method="POST",
            json={
                "releaseType": release_type,
                "description": description,
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ProcessorVersionCreateRequestConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionCreateResponse,
                    construct_type(
                        type_=ProcessorVersionCreateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, processor_id: str, processor_version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ProcessorVersionGetResponse]:
        """
        Retrieve a specific version of a processor in Extend

        Parameters
        ----------
        processor_id : str
            The ID of the processor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        processor_version_id : str
            The ID of the specific processor version to retrieve.

            Example: `"exv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProcessorVersionGetResponse]
            Successfully retrieved processor version
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"processors/{jsonable_encoder(processor_id)}/versions/{jsonable_encoder(processor_version_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProcessorVersionGetResponse,
                    construct_type(
                        type_=ProcessorVersionGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.legacy_list_processors_response import LegacyListProcessorsResponse
from ..types.legacy_processor_type import LegacyProcessorType
from .raw_client import AsyncRawProcessorClient, RawProcessorClient
from .requests.processor_create_request_config import ProcessorCreateRequestConfigParams
from .requests.processor_update_request_config import ProcessorUpdateRequestConfigParams
from .types.processor_create_response import ProcessorCreateResponse
from .types.processor_list_request_sort_by import ProcessorListRequestSortBy
from .types.processor_list_request_sort_dir import ProcessorListRequestSortDir
from .types.processor_update_response import ProcessorUpdateResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProcessorClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawProcessorClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawProcessorClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawProcessorClient
        """
        return self._raw_client

    def list(
        self,
        *,
        type: typing.Optional[LegacyProcessorType] = None,
        next_page_token: typing.Optional[str] = None,
        max_page_size: typing.Optional[int] = None,
        sort_by: typing.Optional[ProcessorListRequestSortBy] = None,
        sort_dir: typing.Optional[ProcessorListRequestSortDir] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> LegacyListProcessorsResponse:
        """
        List all processors in your organization

        Parameters
        ----------
        type : typing.Optional[LegacyProcessorType]
            Filter processors by type

        next_page_token : typing.Optional[str]
            Token for retrieving the next page of results

        max_page_size : typing.Optional[int]
            Maximum number of processors to return per page

        sort_by : typing.Optional[ProcessorListRequestSortBy]
            Field to sort by

        sort_dir : typing.Optional[ProcessorListRequestSortDir]
            Sort direction

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LegacyListProcessorsResponse
            Successfully retrieved processors

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.processor.list()
        """
        _response = self._raw_client.list(
            type=type,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            sort_by=sort_by,
            sort_dir=sort_dir,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        name: str,
        type: LegacyProcessorType,
        clone_processor_id: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorCreateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorCreateResponse:
        """
        Create a new processor in Extend, optionally cloning from an existing processor

        Parameters
        ----------
        name : str
            The name of the new processor

        type : LegacyProcessorType

        clone_processor_id : typing.Optional[str]
            The ID of an existing processor to clone. One of `cloneProcessorId` or `config` must be provided.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        config : typing.Optional[ProcessorCreateRequestConfigParams]
            The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorCreateResponse
            Successfully created processor

        Examples
        --------
        from extend_ai import Extend, LegacyProcessorType

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.processor.create(
            name="My Processor Name",
            type=LegacyProcessorType.EXTRACT,
        )
        """
        _response = self._raw_client.create(
            name=name, type=type, clone_processor_id=clone_processor_id, config=config, request_options=request_options
        )
        return _response.data

    def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorUpdateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorUpdateResponse:
        """
        Update an existing processor in Extend

        Parameters
        ----------
        id : str
            The ID of the processor to update.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name for the processor

        config : typing.Optional[ProcessorUpdateRequestConfigParams]
            The new configuration for the processor. The type of configuration must match the processor type:
            * For classification processors, use `ClassificationConfig`
            * For extraction processors, use `ExtractionConfig`
            * For splitter processors, use `SplitterConfig`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorUpdateResponse
            Successfully updated processor

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.processor.update(
            id="processor_id_here",
        )
        """
        _response = self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data


class AsyncProcessorClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawProcessorClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawProcessorClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawProcessorClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        type: typing.Optional[LegacyProcessorType] = None,
        next_page_token: typing.Optional[str] = None,
        max_page_size: typing.Optional[int] = None,
        sort_by: typing.Optional[ProcessorListRequestSortBy] = None,
        sort_dir: typing.Optional[ProcessorListRequestSortDir] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> LegacyListProcessorsResponse:
        """
        List all processors in your organization

        Parameters
        ----------
        type : typing.Optional[LegacyProcessorType]
            Filter processors by type

        next_page_token : typing.Optional[str]
            Token for retrieving the next page of results

        max_page_size : typing.Optional[int]
            Maximum number of processors to return per page

        sort_by : typing.Optional[ProcessorListRequestSortBy]
            Field to sort by

        sort_dir : typing.Optional[ProcessorListRequestSortDir]
            Sort direction

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LegacyListProcessorsResponse
            Successfully retrieved processors

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.processor.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            type=type,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            sort_by=sort_by,
            sort_dir=sort_dir,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        name: str,
        type: LegacyProcessorType,
        clone_processor_id: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorCreateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorCreateResponse:
        """
        Create a new processor in Extend, optionally cloning from an existing processor

        Parameters
        ----------
        name : str
            The name of the new processor

        type : LegacyProcessorType

        clone_processor_id : typing.Optional[str]
            The ID of an existing processor to clone. One of `cloneProcessorId` or `config` must be provided.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        config : typing.Optional[ProcessorCreateRequestConfigParams]
            The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorCreateResponse
            Successfully created processor

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend, LegacyProcessorType

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.processor.create(
                name="My Processor Name",
                type=LegacyProcessorType.EXTRACT,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name, type=type, clone_processor_id=clone_processor_id, config=config, request_options=request_options
        )
        return _response.data

    async def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorUpdateRequestConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorUpdateResponse:
        """
        Update an existing processor in Extend

        Parameters
        ----------
        id : str
            The ID of the processor to update.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name for the processor

        config : typing.Optional[ProcessorUpdateRequestConfigParams]
            The new configuration for the processor. The type of configuration must match the processor type:
            * For classification processors, use `ClassificationConfig`
            * For extraction processors, use `ExtractionConfig`
            * For splitter processors, use `SplitterConfig`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorUpdateResponse
            Successfully updated processor

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.processor.update(
                id="processor_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .bounding_box import BoundingBoxParams


class ParseRunOutputOcrWordsItemParams(typing_extensions.TypedDict):
    content: str
    """
    The text content of the word.
    """

    bounding_box: typing_extensions.Annotated[BoundingBoxParams, FieldMetadata(alias="boundingBox")]
    """
    The bounding box coordinates of the word.
    """

    confidence: float
    """
    The confidence score of the OCR detection for this word, between 0 and 1.
    """

    page_number: typing_extensions.Annotated[float, FieldMetadata(alias="pageNumber")]
    """
    The page number where the word was detected.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .legacy_list_processors_processor import LegacyListProcessorsProcessorParams


class LegacyListProcessorsResponseParams(typing_extensions.TypedDict):
    success: bool
    """
    Indicates the request was successful
    """

    warning: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Optional warning message
    """

    processors: typing.Sequence[LegacyListProcessorsProcessorParams]
    """
    Array of processors
    """

    next_page_token: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="nextPageToken")]
    ]
    """
    Token for retrieving the next page of results. Will be null if there are no more results.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class EditTextOptionsParams(typing_extensions.TypedDict):
    """
    Text styling options for text fields
    """

    font_size: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="fontSize")]]
    """
    Font size in points
    """

    font_color: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Sequence[float], FieldMetadata(alias="fontColor")]
    ]
    """
    RGB color values (0-255) for text color
    """

    font: typing_extensions.NotRequired[str]
    """
    Font family name
    """

    combing: typing_extensions.NotRequired[bool]
    """
    Whether this is a combed field (like SSN fields with individual character boxes)
    """

    max_length: typing_extensions.NotRequired[typing_extensions.Annotated[int, FieldMetadata(alias="maxLength")]]
    """
    Maximum number of characters allowed
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .citation_page import CitationPageParams
from .polygon import PolygonParams


class CitationParams(typing_extensions.TypedDict):
    page: typing_extensions.NotRequired[CitationPageParams]
    reference_text: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="referenceText")]
    ]
    """
    The text that was referenced
    """

    polygon: typing_extensions.NotRequired[typing.Sequence[PolygonParams]]
    """
    Array of points defining the polygon around the referenced text
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..requests.classify_config import ClassifyConfigParams
from ..types.classify_run import ClassifyRun
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.processor_run_status import ProcessorRunStatus
from ..types.run_metadata import RunMetadata
from ..types.run_priority import RunPriority
from ..types.run_source import RunSource
from ..types.run_source_id import RunSourceId
from ..types.sort_by import SortBy
from ..types.sort_dir import SortDir
from .raw_client import AsyncRawClassifyRunsClient, RawClassifyRunsClient
from .requests.classify_runs_create_request_classifier import ClassifyRunsCreateRequestClassifierParams
from .requests.classify_runs_create_request_file import ClassifyRunsCreateRequestFileParams
from .types.classify_runs_delete_response import ClassifyRunsDeleteResponse
from .types.classify_runs_list_response import ClassifyRunsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ClassifyRunsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawClassifyRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawClassifyRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawClassifyRunsClient
        """
        return self._raw_client

    def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        classifier_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRunsListResponse:
        """
        List all classify runs.

        Returns a summary of each run. Use `GET /classify_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        classifier_id : typing.Optional[str]
            Filters classify runs by the classifier ID. If not provided, all classify runs are returned.

            Example: `"cl_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRunsListResponse
            You will get a list of summaries for each classify run. These are shortened versions of the full classify run object.

            To get the full object, use the [Get Classify Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/classify/get-classify-run) endpoint.

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify_runs.list(
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            status=status,
            classifier_id=classifier_id,
            source_id=source_id,
            source=source,
            file_name_contains=file_name_contains,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        file: ClassifyRunsCreateRequestFileParams,
        classifier: typing.Optional[ClassifyRunsCreateRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRun:
        """
        Classify a document using an existing classifier or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the Get Classify Run endpoint for results.

        Parameters
        ----------
        file : ClassifyRunsCreateRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRunsCreateRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Classification completed successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify_runs.create(
            classifier={"id": "cl_1234567890"},
            file={"url": "https://example.com/document.pdf"},
        )
        """
        _response = self._raw_client.create(
            file=file,
            classifier=classifier,
            config=config,
            priority=priority,
            metadata=metadata,
            request_options=request_options,
        )
        return _response.data

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClassifyRun:
        """
        Retrieve details about a specific classify run, including its status and outputs.

        A common use case for this endpoint is to poll for the status and final output of a classify run when using the [Create Classify Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/classify/create-classify-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this classify run.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Successfully retrieved classify run

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify_runs.retrieve(
            id="classify_run_id_here",
        )
        """
        _response = self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClassifyRunsDeleteResponse:
        """
        Delete a classify run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the classify run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRunsDeleteResponse
            Classifier run deleted successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify_runs.delete(
            id="id",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def cancel(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClassifyRun:
        """
        Cancel an in-progress classify run.

        Note: Only classify runs with a status of `"PROCESSING"` can be cancelled. Classifier runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the classify run to cancel.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Classifier run cancelled successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify_runs.cancel(
            id="classify_run_id_here",
        )
        """
        _response = self._raw_client.cancel(id, request_options=request_options)
        return _response.data


class AsyncClassifyRunsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawClassifyRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawClassifyRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawClassifyRunsClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        classifier_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRunsListResponse:
        """
        List all classify runs.

        Returns a summary of each run. Use `GET /classify_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        classifier_id : typing.Optional[str]
            Filters classify runs by the classifier ID. If not provided, all classify runs are returned.

            Example: `"cl_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRunsListResponse
            You will get a list of summaries for each classify run. These are shortened versions of the full classify run object.

            To get the full object, use the [Get Classify Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/classify/get-classify-run) endpoint.

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify_runs.list(
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            status=status,
            classifier_id=classifier_id,
            source_id=source_id,
            source=source,
            file_name_contains=file_name_contains,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        file: ClassifyRunsCreateRequestFileParams,
        classifier: typing.Optional[ClassifyRunsCreateRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRun:
        """
        Classify a document using an existing classifier or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the Get Classify Run endpoint for results.

        Parameters
        ----------
        file : ClassifyRunsCreateRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRunsCreateRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Classification completed successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify_runs.create(
                classifier={"id": "cl_1234567890"},
                file={"url": "https://example.com/document.pdf"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            file=file,
            classifier=classifier,
            config=config,
            priority=priority,
            metadata=metadata,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClassifyRun:
        """
        Retrieve details about a specific classify run, including its status and outputs.

        A common use case for this endpoint is to poll for the status and final output of a classify run when using the [Create Classify Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/classify/create-classify-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this classify run.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Successfully retrieved classify run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify_runs.retrieve(
                id="classify_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ClassifyRunsDeleteResponse:
        """
        Delete a classify run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the classify run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRunsDeleteResponse
            Classifier run deleted successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify_runs.delete(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def cancel(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClassifyRun:
        """
        Cancel an in-progress classify run.

        Note: Only classify runs with a status of `"PROCESSING"` can be cancelled. Classifier runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the classify run to cancel.

            Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Classifier run cancelled successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify_runs.cancel(
                id="classify_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.cancel(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItemParams


class ParseRunOutputOcrParams(typing_extensions.TypedDict):
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """

    words: typing_extensions.NotRequired[typing.Sequence[ParseRunOutputOcrWordsItemParams]]
    """
    An array of individual words detected by OCR.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .page_ranges import PageRanges
from .parse_config_advanced_options_excel_parsing_mode import ParseConfigAdvancedOptionsExcelParsingMode
from .parse_config_advanced_options_return_ocr import ParseConfigAdvancedOptionsReturnOcr


class ParseConfigAdvancedOptions(UncheckedBaseModel):
    page_rotation_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="pageRotationEnabled")
    ] = pydantic.Field(alias="pageRotationEnabled", default=None)
    """
    Whether to automatically detect and correct page rotation.
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = (
        pydantic.Field(alias="pageRanges", default=None)
    )
    excel_parsing_mode: typing_extensions.Annotated[
        typing.Optional[ParseConfigAdvancedOptionsExcelParsingMode], FieldMetadata(alias="excelParsingMode")
    ] = pydantic.Field(alias="excelParsingMode", default=None)
    """
    Controls how Excel files are parsed.
    
    * `basic`: Fast, deterministic parsing.
    * `advanced`: Enable layout block detection for complex spreadsheets.
    
    For `.xls` files, `basic` mode is always used.
    """

    excel_skip_hidden_content: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="excelSkipHiddenContent")
    ] = pydantic.Field(alias="excelSkipHiddenContent", default=None)
    """
    Whether to exclude hidden rows, columns, and sheets when parsing Excel files.
    """

    vertical_grouping_threshold: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="verticalGroupingThreshold")
    ] = pydantic.Field(alias="verticalGroupingThreshold", default=None)
    """
    Multiplier for the Y-axis threshold used to determine if text blocks should be placed on the same line or not (0.1-5.0, default 1.0). Higher values group elements that are further apart vertically. Only applies when the spatial target is set.
    """

    return_ocr: typing_extensions.Annotated[
        typing.Optional[ParseConfigAdvancedOptionsReturnOcr], FieldMetadata(alias="returnOcr")
    ] = pydantic.Field(alias="returnOcr", default=None)
    """
    Options for returning raw OCR data in the response.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.api_version_enum import ApiVersionEnum
from ..types.webhook_endpoint_event_type import WebhookEndpointEventType
from ..types.webhook_endpoint_status import WebhookEndpointStatus
from .webhook_advanced_options import WebhookAdvancedOptionsParams


class WebhookEndpointCreateParams(typing_extensions.TypedDict):
    """
    The response when creating a webhook endpoint. Includes the `signingSecret`, which is only returned on creation and cannot be retrieved again.
    """

    object: typing.Literal["webhook_endpoint"]
    id: str
    """
    Unique identifier for the webhook endpoint.
    """

    url: str
    """
    The URL that webhook events are sent to.
    """

    name: str
    """
    A human-readable name for the webhook endpoint.
    """

    status: WebhookEndpointStatus
    enabled_events: typing_extensions.Annotated[
        typing.Sequence[WebhookEndpointEventType], FieldMetadata(alias="enabledEvents")
    ]
    """
    The list of event types this endpoint is subscribed to at the global level. These are events that are not scoped to a specific resource.
    """

    api_version: typing_extensions.Annotated[ApiVersionEnum, FieldMetadata(alias="apiVersion")]
    advanced_options: typing_extensions.Annotated[
        typing.Optional[WebhookAdvancedOptionsParams], FieldMetadata(alias="advancedOptions")
    ]
    """
    Advanced configuration options for the webhook endpoint, including custom headers and payload delivery settings.
    """

    signing_secret: typing_extensions.Annotated[str, FieldMetadata(alias="signingSecret")]
    """
    The signing secret used to verify webhook payloads. This is only returned when creating the endpoint and cannot be retrieved again.
    
    Store it securely — you will need it to verify webhook signatures.
    """

    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")]
    """
    The date and time the webhook endpoint was created.
    """



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .created_at import CreatedAt
from .extract_config import ExtractConfig
from .extract_output import ExtractOutput
from .extract_output_edits import ExtractOutputEdits
from .extractor_summary import ExtractorSummary
from .extractor_version_summary import ExtractorVersionSummary
from .file_summary import FileSummary
from .processor_run_status import ProcessorRunStatus
from .run_metadata import RunMetadata
from .run_usage import RunUsage
from .updated_at import UpdatedAt


class ExtractRun(UncheckedBaseModel):
    """
    Extract run object.
    """

    object: typing.Literal["extract_run"] = pydantic.Field(default="extract_run")
    """
    The type of object. Will always be `"extract_run"`.
    """

    id: str = pydantic.Field()
    """
    The unique identifier for this extract run.
    
    Example: `"exr_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    extractor: typing.Optional[ExtractorSummary] = pydantic.Field(default=None)
    """
    The extractor that was used for this run.
    
    **Availability:** Present when an extractor reference was provided. Not present when using inline `config`.
    """

    extractor_version: typing_extensions.Annotated[
        typing.Optional[ExtractorVersionSummary], FieldMetadata(alias="extractorVersion")
    ] = pydantic.Field(alias="extractorVersion", default=None)
    """
    The version of the extractor that was used for this run.
    
    **Availability:** Present when an extractor reference was provided. Not present when using inline `config`.
    """

    status: ProcessorRunStatus
    output: typing.Optional[ExtractOutput] = pydantic.Field(default=None)
    """
    The final output, either reviewed or initial. This is a union of two possible shapes:
    
    - **[JSON Schema output](https://docs.extend.ai/2026-02-09/product/extraction/output-types):** The current output format, returned for runs created with a JSON Schema config.
    - **[Legacy output](https://docs.extend.ai/2025-04-21/product/legacy/output-type-legacy):** A legacy output format from a previous API version. This shape is only returned for runs that were originally created with a legacy config.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    initial_output: typing_extensions.Annotated[
        typing.Optional[ExtractOutput], FieldMetadata(alias="initialOutput")
    ] = pydantic.Field(alias="initialOutput", default=None)
    """
    The initial output from the extract run, before any review edits.
    
    **Availability:** Present when `reviewed` is `true`.
    """

    reviewed_output: typing_extensions.Annotated[
        typing.Optional[ExtractOutput], FieldMetadata(alias="reviewedOutput")
    ] = pydantic.Field(alias="reviewedOutput", default=None)
    """
    The output after human review.
    
    **Availability:** Present when `reviewed` is `true`.
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    
    Possible values include:
    * `ABORTED` - The run was aborted by the user
    * `INTERNAL_ERROR` - An unexpected internal error occurred
    * `FAILED_TO_PROCESS_FILE` - Failed to process the file (e.g., OCR failure, file access issues)
    * `INVALID_PROCESSOR` - The processor configuration is invalid
    * `INVALID_CONFIGURATION` - The provided configuration is incompatible with the selected model
    * `PARSING_ERROR` - Failed to parse the extraction output
    * `PRE_PROCESSING_FAILURE` - An error occurred during preprocessing (e.g., chunking)
    * `POST_PROCESSING_FAILURE` - An error occurred during postprocessing
    * `OUT_OF_CREDITS` - Insufficient credits to run the extraction
    
    **Note:** Additional failure reasons may be added in the future. Your integration should handle unknown values gracefully.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(alias="failureMessage", default=None)
    )
    """
    A detailed message about the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    metadata: typing.Optional[RunMetadata] = pydantic.Field(default=None)
    """
    Any metadata that was provided when creating the extract run.
    
    **Availability:** Present when metadata was provided during creation.
    """

    reviewed: bool = pydantic.Field()
    """
    Indicates whether the run has been reviewed by a human.
    """

    edited: bool = pydantic.Field()
    """
    Indicates whether the run results have been edited during review.
    """

    edits: typing.Optional[typing.Dict[str, typing.Optional[ExtractOutputEdits]]] = pydantic.Field(default=None)
    """
    Details of edits made during review.
    
    **Availability:** Present when `edited` is `true`.
    """

    config: ExtractConfig = pydantic.Field()
    """
    The configuration used for this extract run. This is a union of two possible shapes:
    
    - **[JSON Schema config](https://docs.extend.ai/2026-02-09/product/extraction/schema):** The current config format. All runs created through this API version use this shape.
    - **[Legacy config](https://docs.extend.ai/2025-04-21/product/legacy/legacy-schema):** A fields-array config from a previous API version. This shape is only returned when retrieving runs that were originally created with the legacy format. This API version does not support creating runs with legacy configs.
    """

    file: FileSummary = pydantic.Field()
    """
    The file that was processed.
    """

    parse_run_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="parseRunId")] = pydantic.Field(
        alias="parseRunId", default=None
    )
    """
    The ID of the parse run that was used for this extract run.
    
    **Availability:** Present when a parse run was created.
    """

    dashboard_url: typing_extensions.Annotated[str, FieldMetadata(alias="dashboardUrl")] = pydantic.Field(
        alias="dashboardUrl"
    )
    """
    The URL to view the extract run in the Extend dashboard.
    """

    usage: typing.Optional[RunUsage] = pydantic.Field(default=None)
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")] = pydantic.Field(
        alias="updatedAt"
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ExtractRun)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult

LegacyProvidedFieldsArrayOutputParams = typing.Dict[str, LegacyProvidedExtractionFieldResult]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_list_processors_processor_version import LegacyListProcessorsProcessorVersion
from .legacy_processor_type import LegacyProcessorType


class LegacyListProcessorsProcessor(UncheckedBaseModel):
    object: typing.Literal["document_processor"] = pydantic.Field(default="document_processor")
    """
    The type of response. In this case, it will always be `"document_processor"`.
    """

    id: str = pydantic.Field()
    """
    The ID of the processor.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str = pydantic.Field()
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    type: LegacyProcessorType
    versions: typing.List[LegacyListProcessorsProcessorVersion] = pydantic.Field()
    """
    Array of all versions for this processor
    """

    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )
    """
    The time (in UTC) at which the processor was created. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")] = pydantic.Field(
        alias="updatedAt"
    )
    """
    The time (in UTC) at which the processor was last updated. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T16:45:00Z"`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class LegacyExtendErrorParams(typing_extensions.TypedDict):
    code: str
    """
    Error code identifying the type of error
    """

    message: str
    """
    Human-readable error message
    """

    request_id: typing_extensions.Annotated[str, FieldMetadata(alias="requestId")]
    """
    Unique request identifier for support purposes
    """

    retryable: bool
    """
    Whether the request can be retried
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .merge_extract_result import MergeExtractResultParams
from .merge_extract_step_run_step import MergeExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class MergeExtractStepRunParams(StepRunBaseParams):
    step: MergeExtractStepRunStepParams
    result: typing.Optional[MergeExtractResultParams]
    """
    The result of this merge extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .rule_validation_result import RuleValidationResultParams
from .rule_validation_step_run_step import RuleValidationStepRunStepParams
from .step_run_base import StepRunBaseParams


class RuleValidationStepRunParams(StepRunBaseParams):
    step: RuleValidationStepRunStepParams
    result: typing.Optional[RuleValidationResultParams]
    """
    The result of this rule validation step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_payload_format import WebhookPayloadFormat


class WebhookPayloadOptions(UncheckedBaseModel):
    """
    Configuration for how webhook payloads are delivered.
    """

    format: WebhookPayloadFormat
    url_threshold_bytes: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="urlThresholdBytes")] = (
        pydantic.Field(alias="urlThresholdBytes", default=None)
    )
    """
    When `format` is `url`, payloads larger than this threshold (in bytes) are delivered as a signed download URL instead of inline JSON. Only applicable when `format` is `url`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .file_summary import FileSummaryParams
from .provided_processor_output import ProvidedProcessorOutputParams


class EvaluationSetItemParams(typing_extensions.TypedDict):
    object: typing.Literal["evaluation_set_item"]
    """
    The type of object. In this case, it will always be `"evaluation_set_item"`.
    """

    id: str
    """
    The ID of the evaluation set item.
    
    Example: `"evi_kR9mNP12Qw4yTv8BdR3H"`
    """

    evaluation_set_id: typing_extensions.Annotated[str, FieldMetadata(alias="evaluationSetId")]
    """
    The ID of the evaluation set that this item belongs to.
    
    Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`
    """

    file: FileSummaryParams
    """
    A summary of the file associated with the evaluation set item.
    """

    expected_output: typing_extensions.Annotated[ProvidedProcessorOutputParams, FieldMetadata(alias="expectedOutput")]
    """
    The expected output that will be used to evaluate the performance of the extractor, classifier, or splitter associated with the evaluation set. This must conform to the output schema of the entity associated with the evaluation set.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class BatchProcessorRunSource(enum.StrEnum):
    """
    The source of the batch processor run:
    * `"EVAL_SET"` - The batch processor run was made from an evaluation set. The `sourceId` will be the ID of the evaluation set (e.g., `"ev_1234"`)
    * `"PLAYGROUND"` - The batch processor run was made from the playground. The `sourceId` will not be set
    * `"STUDIO"` - The batch processor run was made for a processor in Studio. The `sourceId` will be the ID of the processor (e.g., `"ex_1234"`)
    """

    EVAL_SET = "EVAL_SET"
    PLAYGROUND = "PLAYGROUND"
    STUDIO = "STUDIO"
    _UNKNOWN = "__BATCHPROCESSORRUNSOURCE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "BatchProcessorRunSource":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        eval_set: typing.Callable[[], T_Result],
        playground: typing.Callable[[], T_Result],
        studio: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is BatchProcessorRunSource.EVAL_SET:
            return eval_set()
        if self is BatchProcessorRunSource.PLAYGROUND:
            return playground()
        if self is BatchProcessorRunSource.STUDIO:
            return studio()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FileFromUrl(UncheckedBaseModel):
    url: str = pydantic.Field()
    """
    A URL to download the file. For production use cases, we recommend using presigned URLs with a 5-15 minute expiration time.
    
    Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the file. If not set, the file name is taken from the URL.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .edit_run_output_edited_file import EditRunOutputEditedFileParams


class EditRunOutputParams(typing_extensions.TypedDict):
    """
    The output of the edit run.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    edited_file: typing_extensions.Annotated[EditRunOutputEditedFileParams, FieldMetadata(alias="editedFile")]
    """
    Information about the edited output file.
    """

    filled_values: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Dict[str, typing.Any], FieldMetadata(alias="filledValues")]
    ]
    """
    The field values that were filled into the document. Keys correspond to the property names in the schema. Will not be present if no values were filled.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyListProcessorsProcessorVersionParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this version of the document processor.
    
    Example: `"exv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    version: str
    """
    The version number or identifier for this processor version.
    
    Example: `"3"`
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditConfigAdvancedOptions(UncheckedBaseModel):
    """
    Advanced options for the edit operation.
    """

    table_parsing_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="tableParsingEnabled")
    ] = pydantic.Field(alias="tableParsingEnabled", default=None)
    """
    Whether to parse table regions as arrays of objects. Defaults to `false`.
    """

    flatten_pdf: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="flattenPdf")] = pydantic.Field(
        alias="flattenPdf", default=None
    )
    """
    Whether to flatten the PDF (form widgets will not be editable with a PDF edit). Defaults to `true`.
    """

    radio_enums_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="radioEnumsEnabled")
    ] = pydantic.Field(alias="radioEnumsEnabled", default=None)
    """
    Whether to model radio fields as enums. This ensures only one radio widget is filled. Defaults to false.
    """

    native_fields_only: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="nativeFieldsOnly")] = (
        pydantic.Field(alias="nativeFieldsOnly", default=None)
    )
    """
    If enabled, only native AcroForm from the PDF will be imported and used in the schema (skips object detection). Defaults to false.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt
from ..types.workflow_run_status import WorkflowRunStatus
from .run_usage import RunUsageParams
from .workflow_summary import WorkflowSummaryParams
from .workflow_version_summary import WorkflowVersionSummaryParams


class WorkflowRunSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["workflow_run"]
    """
    The type of object. In this case, it will always be `"workflow_run"`.
    """

    id: str
    """
    The ID of the workflow run.
    
    Example: `"workflow_run_Zk9mNP12Qw4-yTv8BdR3H"`
    """

    status: WorkflowRunStatus
    workflow: WorkflowSummaryParams
    workflow_version: typing_extensions.Annotated[WorkflowVersionSummaryParams, FieldMetadata(alias="workflowVersion")]
    dashboard_url: typing_extensions.Annotated[str, FieldMetadata(alias="dashboardUrl")]
    """
    A URL to view this workflow run in the Extend dashboard.
    
    Example: `"https://dashboard.extend.ai/workflows/workflow_run_xKm9pNv3qWsY_jL2tR5Dh"`
    """

    reviewed_by_user: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="reviewedByUser")]
    """
    The user of the person who reviewed the workflow run. Will be null if the workflow run has not been reviewed.
    
    Example: `"jane.doe@example.com"`
    """

    reviewed_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="reviewedAt")]
    """
    The time (in UTC) at which the workflow run was reviewed. Will follow the RFC 3339 format. Will be null if the workflow run has not been reviewed.
    
    Example: `"2024-03-21T16:45:00Z"`
    """

    initial_run_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="initialRunAt")]
    """
    The time (in UTC) at which the workflow was initially created. Will follow the RFC 3339 format. Will be null if the run hasn't started yet.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    start_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="startTime")]
    """
    The start time (in UTC) that the workflow actually started executing. This occurs after the `initialRunAt` time. Will follow the RFC 3339 format. Will be null if not started.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    end_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="endTime")]
    """
    The end time (in UTC) that the workflow finished. Will follow the RFC 3339 format. Will be null if not finished.
    
    Example: `"2024-03-21T15:35:00Z"`
    """

    batch_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="batchId")]
    """
    The batch ID of the workflow run. If that workflow run was created from a batch of files, all runs in that batch will have the same batch ID.
    
    Example: `"batch_7Ws31-F5"`
    """

    rejection_note: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rejectionNote")]
    """
    The note that was added when the workflow run was rejected.
    
    Example: `"Invalid invoice format"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
    usage: typing.Optional[RunUsageParams]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .file import File
from .json_object import JsonObject
from .legacy_document_processor_run_credits import LegacyDocumentProcessorRunCredits
from .legacy_extraction_output_edits import LegacyExtractionOutputEdits
from .legacy_processor_output import LegacyProcessorOutput
from .legacy_processor_run_config import LegacyProcessorRunConfig
from .legacy_processor_run_merged_processors_item import LegacyProcessorRunMergedProcessorsItem
from .legacy_processor_run_type import LegacyProcessorRunType
from .legacy_processor_status import LegacyProcessorStatus


class LegacyProcessorRun(UncheckedBaseModel):
    object: str = pydantic.Field()
    """
    The type of response. In this case, it will always be `"document_processor_run"`.
    """

    id: str = pydantic.Field()
    """
    The unique identifier for this processor run.
    
    Example: `"exr_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")] = pydantic.Field(
        alias="processorId"
    )
    """
    The ID of the processor used for this run.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_version_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorVersionId")] = pydantic.Field(
        alias="processorVersionId"
    )
    """
    The ID of the specific processor version used.
    """

    processor_name: typing_extensions.Annotated[str, FieldMetadata(alias="processorName")] = pydantic.Field(
        alias="processorName"
    )
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    status: LegacyProcessorStatus
    output: LegacyProcessorOutput = pydantic.Field()
    """
    The final output, either reviewed or initial.
    
    Conforms to the shape of output types and depends on the processor type and configuration shape.
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    If the run failed, indicates the reason for failure.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(alias="failureMessage", default=None)
    )
    """
    If the run failed, provides a detailed message about the failure.
    """

    metadata: typing.Optional[JsonObject] = pydantic.Field(default=None)
    """
    Any metadata that was provided when creating the processor run.
    """

    reviewed: bool = pydantic.Field()
    """
    Indicates whether the run has been reviewed.
    """

    edited: bool = pydantic.Field()
    """
    Indicates whether the run results have been edited.
    """

    edits: typing.Dict[str, LegacyExtractionOutputEdits]
    type: LegacyProcessorRunType = pydantic.Field()
    """
    The type of processor:
    * `"CLASSIFY"` - Classifies documents into categories
    * `"EXTRACT"` - Extracts structured data from documents
    * `"SPLITTER"` - Splits documents into multiple parts
    """

    config: LegacyProcessorRunConfig = pydantic.Field()
    """
    The configuration used for this processor run. The type of configuration will match the processor type.
    """

    initial_output: typing_extensions.Annotated[
        typing.Optional[LegacyProcessorOutput], FieldMetadata(alias="initialOutput")
    ] = pydantic.Field(alias="initialOutput", default=None)
    """
    The initial output from the processor run. The type of output will match the processor type.
    """

    reviewed_output: typing_extensions.Annotated[
        typing.Optional[LegacyProcessorOutput], FieldMetadata(alias="reviewedOutput")
    ] = pydantic.Field(alias="reviewedOutput", default=None)
    """
    The output after review, if any.
    """

    files: typing.List[File] = pydantic.Field()
    """
    Details of the processed files.
    
    If this was a file generated from a splitter processor, this will be the sub file.
    
    See the File object for more details.
    """

    merged_processors: typing_extensions.Annotated[
        typing.List[LegacyProcessorRunMergedProcessorsItem], FieldMetadata(alias="mergedProcessors")
    ] = pydantic.Field(alias="mergedProcessors")
    """
    An array of processors that were merged to create this output. Will be an empty array unless this output was the result of a MergeExtraction step in a workflow.
    """

    url: str = pydantic.Field()
    """
    The URL to view the processor run.
    """

    usage: typing.Optional[LegacyDocumentProcessorRunCredits] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(LegacyProcessorRun)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_config_advanced_options import EditConfigAdvancedOptions
from .edit_root_json import EditRootJson


class EditConfig(UncheckedBaseModel):
    """
    Configuration options for the editing process.
    """

    schema_: typing_extensions.Annotated[typing.Optional[EditRootJson], FieldMetadata(alias="schema")] = pydantic.Field(
        alias="schema", default=None
    )
    instructions: typing.Optional[str] = pydantic.Field(default=None)
    """
    Custom instructions provided for the edit operation.
    """

    advanced_options: typing_extensions.Annotated[
        typing.Optional[EditConfigAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    """
    Advanced options for the edit operation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EditConfig)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class LegacyExtractionOutputEditsParams(typing_extensions.TypedDict):
    """
    A record of edits made to the processor output.
    """

    original_value: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Any, FieldMetadata(alias="originalValue")]
    ]
    """
    The original value before editing.
    """

    edited_value: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Any, FieldMetadata(alias="editedValue")]
    ]
    """
    The value after editing.
    """

    notes: typing_extensions.NotRequired[str]
    """
    Any notes added during editing.
    """

    page: typing_extensions.NotRequired[float]
    """
    The page number where the edit was made.
    """

    field_type: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="fieldType")]]
    """
    The type of the edited field.
    """
